define rsh::rhosts ($user = $title, $ensure = present, $lines = [], $path) {

  validate_array($lines)

  if ! ($ensure in [ 'present', 'absent' ]) {
    fail('ensure parameter must be present or absent')
  }

  file { $path:
    ensure => $ensure ? {
      'present' => 'file',
      'absent'  => 'absent',
    },
    owner   => $user,
    mode    => '0400',
    content => join($lines, "\n"),
  }
  
  if ($user in [ 0, 'root' ]) {
    # root RSH also requires a line in /etc/securetty, and since hosts.equiv
    # doesn't apply to root, we're managing that line together with root's
    # .rhosts file rather than in rsh::servers.

    $securetty = $::osfamily ? {
      'RedHat' => 'rsh',
      default  => 'tty',
    }

    file_line { 'securetty-rsh':
      ensure => $ensure,
      path   => '/etc/securetty',
      line   => $securetty,
    }
  }

}
